/**
 * @brief Add a new radio to the parent
 *
 * @param parent The parent object
 * @return The new object or NULL if it cannot be created
 *
 * @ingroup Elm_Radio
 */
EAPI Evas_Object                 *elm_radio_add(Evas_Object *parent);

#include "efl_ui_radio.eo.legacy.h"